@@ -86,21 +86,8 @@ class Blog(Collection):
         - Rename the archive items so they are not private
     """
 
-    page_content_type: typing.Type[BlogPost] = BlogPost
+    content_type: typing.Type[BlogPost] = BlogPost
     archive_reverse: bool = True
     has_archive: bool = True
     feeds = [RSSFeed]
-
-    @staticmethod
-    def archive_default_sort(cls):
-        """
-        How to sort pages
-
-        Attributes:
-            _archive_default_sort : Any
-                default BlogPost.date
-
-        Todos:
-            - Rename the archive items so they are not private
-        """
-        return cls.date
+    archive_sort = 'date'
