@@ -15,7 +15,13 @@ def parse_content(content: str, matcher: str):
     matchmaker = re.compile(matcher, flags=re.M)
     split_content = content.split('\n\n', maxsplit=1)
     attr_section = split_content[0]
-    base_content = split_content[1]
+
+    if len(split_content) == 2:
+        base_content = split_content[1]
+
+    else:
+        base_content = ''
+
     parsed_attrs = re.split(matchmaker, attr_section)
     content = base_content.strip()
 
