@@ -92,25 +92,7 @@ class Site:
 
         # Make Output Path if it doesn't Exist
         self.output_path = Path(self.output_path)
-
-        # strict deletes the directory and rebuilds it from scratch
-        if self.output_path.exists() and not self.output_path.is_dir():
-            raise ValueError('output path cannot point to an existing file')
-
-        if self.strict and self.output_path.exists():
-            shutil.rmtree(self.output_path)
-
-        self.output_path.mkdir(exist_ok=True)
-
-        # copy a defined static path into output path
-        if Path(self.static_path).is_dir():
-            shutil.copytree(
-                self.static_path,
-                self.output_path.joinpath(self.static_path),
-                dirs_exist_ok=True,
-            )
-
-        # sets the timezone environment variable to the local timezone if not present
+        self.static_path = Path(self.static_path)
 
         os.environ['render_engine_timezone'] = self.timezone or pendulum.local_timezone().name
 
@@ -138,7 +120,6 @@ class Site:
         self.collections.update({collection.title: collection})
 
         for page in collection.pages:
-            logging.info(page.title)
             self.route(cls=page)
 
         if collection.has_archive:
@@ -173,6 +154,26 @@ class Site:
 
 
     def render(self, dry_run: bool = False) -> None:
+
+        # strict deletes the directory and rebuilds it from scratch
+        if self.output_path.exists() and not self.output_path.is_dir():
+            raise ValueError('output path cannot point to an existing file')
+
+        if self.strict and self.output_path.exists():
+            shutil.rmtree(self.output_path)
+
+        self.output_path.mkdir(exist_ok=True)
+
+        # copy a defined static path into output path
+        if Path(self.static_path).is_dir():
+            shutil.copytree(
+                self.static_path,
+                self.output_path.joinpath(self.static_path),
+                dirs_exist_ok=True,
+            )
+
+        # sets the timezone environment variable to the local timezone if not present
+
         for _, collection in self.collections.items():
 
             if collection.subcollections:
